<?php

declare (strict_types=1);
/*
 * This file is part of PHP CS Fixer.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *     Dariusz Rumiński <dariusz.ruminski@gmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */
namespace ps_metrics_module_v4_0_6\PhpCsFixer\Tokenizer\Analyzer;

use ps_metrics_module_v4_0_6\PhpCsFixer\Tokenizer\Tokens;
/**
 * @internal
 */
final class WhitespacesAnalyzer
{
    public static function detectIndent(Tokens $tokens, int $index) : string
    {
        while (\true) {
            $whitespaceIndex = $tokens->getPrevTokenOfKind($index, [[\T_WHITESPACE]]);
            if (null === $whitespaceIndex) {
                return '';
            }
            $whitespaceToken = $tokens[$whitespaceIndex];
            if (\str_contains($whitespaceToken->getContent(), "\n")) {
                break;
            }
            $prevToken = $tokens[$whitespaceIndex - 1];
            if ($prevToken->isGivenKind([\T_OPEN_TAG, \T_COMMENT]) && "\n" === \substr($prevToken->getContent(), -1)) {
                break;
            }
            $index = $whitespaceIndex;
        }
        $explodedContent = \explode("\n", $whitespaceToken->getContent());
        return \end($explodedContent);
    }
}
